# pylint: disable=too-many-lines
# pylint: disable=line-too-long
"""The save commands module.

These commands are used in the following models:
MSO2

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Commands and Queries:

::

    - SAVe:EVENTtable:BUS <QString>
    - SAVe:EVENTtable:MEASUrement <QString>
    - SAVe:EVENTtable:SEARCHTable <QString>
    - SAVe:IMAGe <QString>
    - SAVe:IMAGe:COMPosition {NORMal|INVErted}
    - SAVe:IMAGe:COMPosition?
    - SAVe:IMAGe:VIEWTYpe {FULLScreen}
    - SAVe:IMAGe:VIEWTYpe?
    - SAVe:PLOTData <Qstring>
    - SAVe:REPOrt <QString>
    - SAVe:REPOrt:COMMents <QString>
    - SAVe:REPOrt:COMMents?
    - SAVe:SESsion <QString>
    - SAVe:SETUp <QString>
    - SAVe:SETUp:INCLUDEREFs {OFF|ON|0|1}
    - SAVe:SETUp:INCLUDEREFs?
    - SAVe:WAVEform {CH<x>[_DALL|_SV_NORMal|_SV_AVErage|_SV_MAXHold| _SV_MINHold|_MAG_VS_TIME|_FREQ_VS_TIME| _PHASE_VS_TIME _SV_BASEBAND_IQ]|MATH<x>|REF<x>|ALL| },<QString>
    - SAVe:WAVEform:GATing {NONe|CURSors|SCREEN|RESAMPLE|SELected}
    - SAVe:WAVEform:GATing:RESAMPLErate <NR1>
    - SAVe:WAVEform:GATing:RESAMPLErate?
    - SAVe:WAVEform:GATing?
    - SAVe:WAVEform:SOURCELIst?
"""  # noqa: E501
from typing import Optional, TYPE_CHECKING

from .._helpers import SCPICmdRead, SCPICmdWrite

if TYPE_CHECKING:
    from tm_devices.drivers.pi.pi_device import PIDevice


class SaveWaveformSourcelist(SCPICmdRead):
    """The ``SAVe:WAVEform:SOURCELIst`` command.

    **Description:**
        - This query returns a list of the available waveforms that can be specified as the source
          for the ``SAVe:WAVEform`` command. Source waveforms must have their display mode set to On
          to appear in this list and to be saved.

    **Usage:**
        - Using the ``.query()`` method will send the ``SAVe:WAVEform:SOURCELIst?`` query.
        - Using the ``.verify(value)`` method will send the ``SAVe:WAVEform:SOURCELIst?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - SAVe:WAVEform:SOURCELIst?
    """


class SaveWaveformGatingResamplerate(SCPICmdWrite, SCPICmdRead):
    """The ``SAVe:WAVEform:GATing:RESAMPLErate`` command.

    **Description:**
        - This command saves the waveform data at a sample interval. The resulting saved waveform is
          a resampled version of the original waveform with fewer data points.

    **Usage:**
        - Using the ``.query()`` method will send the ``SAVe:WAVEform:GATing:RESAMPLErate?`` query.
        - Using the ``.verify(value)`` method will send the ``SAVe:WAVEform:GATing:RESAMPLErate?``
          query and raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the
          ``SAVe:WAVEform:GATing:RESAMPLErate value`` command.

    **SCPI Syntax:**

    ::

        - SAVe:WAVEform:GATing:RESAMPLErate <NR1>
        - SAVe:WAVEform:GATing:RESAMPLErate?

    **Info:**
        - ``<NR1>`` specifies the resample interval.
    """


class SaveWaveformGating(SCPICmdWrite, SCPICmdRead):
    """The ``SAVe:WAVEform:GATing`` command.

    **Description:**
        - This command specifies the method to save a specified part of the waveform data or the
          entire waveform.

    **Usage:**
        - Using the ``.query()`` method will send the ``SAVe:WAVEform:GATing?`` query.
        - Using the ``.verify(value)`` method will send the ``SAVe:WAVEform:GATing?`` query and
          raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``SAVe:WAVEform:GATing value`` command.

    **SCPI Syntax:**

    ::

        - SAVe:WAVEform:GATing {NONe|CURSors|SCREEN|RESAMPLE|SELected}
        - SAVe:WAVEform:GATing?

    **Info:**
        - ``NONe`` saves the full waveform data.
        - ``CURSors`` saves the waveform data located between the vertical cursors.
        - ``SCREEN`` saves the waveform data that is on the screen. Nothing outside the waveform
          will be saved.
        - ``RESAMPLE`` saves the waveform data at a sample interval set by the user. The resulting
          saved waveform is a resampled version of the original waveform with fewer data points.
        - ``SELected`` saves the data from the currently selected history or FastFrame acquisition.

    Properties:
        - ``.resamplerate``: The ``SAVe:WAVEform:GATing:RESAMPLErate`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._resamplerate = SaveWaveformGatingResamplerate(
            device, f"{self._cmd_syntax}:RESAMPLErate"
        )

    @property
    def resamplerate(self) -> SaveWaveformGatingResamplerate:
        """Return the ``SAVe:WAVEform:GATing:RESAMPLErate`` command.

        **Description:**
            - This command saves the waveform data at a sample interval. The resulting saved
              waveform is a resampled version of the original waveform with fewer data points.

        **Usage:**
            - Using the ``.query()`` method will send the ``SAVe:WAVEform:GATing:RESAMPLErate?``
              query.
            - Using the ``.verify(value)`` method will send the
              ``SAVe:WAVEform:GATing:RESAMPLErate?`` query and raise an AssertionError if the
              returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the
              ``SAVe:WAVEform:GATing:RESAMPLErate value`` command.

        **SCPI Syntax:**

        ::

            - SAVe:WAVEform:GATing:RESAMPLErate <NR1>
            - SAVe:WAVEform:GATing:RESAMPLErate?

        **Info:**
            - ``<NR1>`` specifies the resample interval.
        """
        return self._resamplerate


class SaveWaveform(SCPICmdWrite, SCPICmdRead):
    """The ``SAVe:WAVEform`` command.

    **Description:**
        - This command saves the specified waveform(s) to the specified destination file.

    **Usage:**
        - Using the ``.write(value)`` method will send the ``SAVe:WAVEform value`` command.

    **SCPI Syntax:**

    ::

        - SAVe:WAVEform {CH<x>[_DALL|_SV_NORMal|_SV_AVErage|_SV_MAXHold| _SV_MINHold|_MAG_VS_TIME|_FREQ_VS_TIME| _PHASE_VS_TIME _SV_BASEBAND_IQ]|MATH<x>|REF<x>|ALL| },<QString>

    **Info:**
        - ``<x>`` is the number of the analog channel (CH<x>), math (MATH<x>), or reference (REF<x>)
          waveform source used to save the waveform data.
        - ``_DALL`` saves the digital channel waveform data of the specified channel.
        - ``_SV_NORMal`` saves the Normal Spectrum view waveform of the specified channel.
        - ``_SV_AVErage`` saves the Average Spectrum view waveform of the specified channel.
        - ``_SV_MAXHold`` saves the Maximum Hold Spectrum view waveform of the specified channel.
        - ``_SV_MINHold`` saves the Minimum Hold Spectrum view waveform of the specified channel.
        - ``_MAG_VS_TIME`` saves the Magnitude vs.
        - ``_FREQ_VS_TIME`` saves the Freuency vs.
        - ``_PHASE_VS_TIME`` saves the Phase vs.
        - ``_SV_BASEBAND_IQ`` saves the baseband I & Q data of the specified channel.
        - ``ALL`` saves all displayed analog, math, and reference waveforms to individual files.
        - ``<Qstring>`` is a quoted string that defines the path and file name to use to save the
          specified file, in the format '[<path>]<filename.
        - ``<path>`` uses the form '<drive>/<dir>.
        - ``<filename>`` sets the file name to use to create the file.
        - ``<.ext>`` sets the file format to which to save the data.

    Properties:
        - ``.gating``: The ``SAVe:WAVEform:GATing`` command.
        - ``.sourcelist``: The ``SAVe:WAVEform:SOURCELIst`` command.
    """  # noqa: E501

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._gating = SaveWaveformGating(device, f"{self._cmd_syntax}:GATing")
        self._sourcelist = SaveWaveformSourcelist(device, f"{self._cmd_syntax}:SOURCELIst")

    @property
    def gating(self) -> SaveWaveformGating:
        """Return the ``SAVe:WAVEform:GATing`` command.

        **Description:**
            - This command specifies the method to save a specified part of the waveform data or the
              entire waveform.

        **Usage:**
            - Using the ``.query()`` method will send the ``SAVe:WAVEform:GATing?`` query.
            - Using the ``.verify(value)`` method will send the ``SAVe:WAVEform:GATing?`` query and
              raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``SAVe:WAVEform:GATing value``
              command.

        **SCPI Syntax:**

        ::

            - SAVe:WAVEform:GATing {NONe|CURSors|SCREEN|RESAMPLE|SELected}
            - SAVe:WAVEform:GATing?

        **Info:**
            - ``NONe`` saves the full waveform data.
            - ``CURSors`` saves the waveform data located between the vertical cursors.
            - ``SCREEN`` saves the waveform data that is on the screen. Nothing outside the waveform
              will be saved.
            - ``RESAMPLE`` saves the waveform data at a sample interval set by the user. The
              resulting saved waveform is a resampled version of the original waveform with fewer
              data points.
            - ``SELected`` saves the data from the currently selected history or FastFrame
              acquisition.

        Sub-properties:
            - ``.resamplerate``: The ``SAVe:WAVEform:GATing:RESAMPLErate`` command.
        """
        return self._gating

    @property
    def sourcelist(self) -> SaveWaveformSourcelist:
        """Return the ``SAVe:WAVEform:SOURCELIst`` command.

        **Description:**
            - This query returns a list of the available waveforms that can be specified as the
              source for the ``SAVe:WAVEform`` command. Source waveforms must have their display
              mode set to On to appear in this list and to be saved.

        **Usage:**
            - Using the ``.query()`` method will send the ``SAVe:WAVEform:SOURCELIst?`` query.
            - Using the ``.verify(value)`` method will send the ``SAVe:WAVEform:SOURCELIst?`` query
              and raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - SAVe:WAVEform:SOURCELIst?
        """
        return self._sourcelist


class SaveSetupIncluderefs(SCPICmdWrite, SCPICmdRead):
    """The ``SAVe:SETUp:INCLUDEREFs`` command.

    **Description:**
        - This command sets or queries whether displayed reference waveforms are to be included in
          saved setups.

    **Usage:**
        - Using the ``.query()`` method will send the ``SAVe:SETUp:INCLUDEREFs?`` query.
        - Using the ``.verify(value)`` method will send the ``SAVe:SETUp:INCLUDEREFs?`` query and
          raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``SAVe:SETUp:INCLUDEREFs value`` command.

    **SCPI Syntax:**

    ::

        - SAVe:SETUp:INCLUDEREFs {OFF|ON|0|1}
        - SAVe:SETUp:INCLUDEREFs?

    **Info:**
        - ``OFF`` specifies not including displayed reference waveforms in saved setups.
        - ``ON`` specifies including displayed reference waveforms in saved setups.
        - ``0`` specifies not including displayed reference waveforms in saved setups.
        - ``1`` specifies including displayed reference waveforms in saved setups.
    """


class SaveSetup(SCPICmdWrite, SCPICmdRead):
    """The ``SAVe:SETUp`` command.

    **Description:**
        - Saves the current instrument state to the specified file.

    **Usage:**
        - Using the ``.write(value)`` method will send the ``SAVe:SETUp value`` command.

    **SCPI Syntax:**

    ::

        - SAVe:SETUp <QString>

    **Info:**
        - ``<QString>`` is a quoted string that is the complete path specification. If a file name
          or path is specified, the file is expected to be located in a directory relative to the
          current working directory (specified by ``FILESYSTEM:CWD``) unless a complete path is
          specified.

    Properties:
        - ``.includerefs``: The ``SAVe:SETUp:INCLUDEREFs`` command.
    """

    _WRAP_ARG_WITH_QUOTES = True

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._includerefs = SaveSetupIncluderefs(device, f"{self._cmd_syntax}:INCLUDEREFs")

    @property
    def includerefs(self) -> SaveSetupIncluderefs:
        """Return the ``SAVe:SETUp:INCLUDEREFs`` command.

        **Description:**
            - This command sets or queries whether displayed reference waveforms are to be included
              in saved setups.

        **Usage:**
            - Using the ``.query()`` method will send the ``SAVe:SETUp:INCLUDEREFs?`` query.
            - Using the ``.verify(value)`` method will send the ``SAVe:SETUp:INCLUDEREFs?`` query
              and raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``SAVe:SETUp:INCLUDEREFs value``
              command.

        **SCPI Syntax:**

        ::

            - SAVe:SETUp:INCLUDEREFs {OFF|ON|0|1}
            - SAVe:SETUp:INCLUDEREFs?

        **Info:**
            - ``OFF`` specifies not including displayed reference waveforms in saved setups.
            - ``ON`` specifies including displayed reference waveforms in saved setups.
            - ``0`` specifies not including displayed reference waveforms in saved setups.
            - ``1`` specifies including displayed reference waveforms in saved setups.
        """
        return self._includerefs


class SaveSession(SCPICmdWrite):
    """The ``SAVe:SESsion`` command.

    **Description:**
        - Saves the state of the instrument, including reference waveforms, to a saved session file.

    **Usage:**
        - Using the ``.write(value)`` method will send the ``SAVe:SESsion value`` command.

    **SCPI Syntax:**

    ::

        - SAVe:SESsion <QString>

    **Info:**
        - ``<QString>`` is the file path that specifies the location to save the specified
          instrument session file. If a file name or path is specified, the file is expected to be
          located in a directory relative to the current working directory (specified by.
    """

    _WRAP_ARG_WITH_QUOTES = True


class SaveReportComments(SCPICmdWrite, SCPICmdRead):
    """The ``SAVe:REPOrt:COMMents`` command.

    **Description:**
        - This command sets or queries the comments to be included in saved report files.

    **Usage:**
        - Using the ``.query()`` method will send the ``SAVe:REPOrt:COMMents?`` query.
        - Using the ``.verify(value)`` method will send the ``SAVe:REPOrt:COMMents?`` query and
          raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``SAVe:REPOrt:COMMents value`` command.

    **SCPI Syntax:**

    ::

        - SAVe:REPOrt:COMMents <QString>
        - SAVe:REPOrt:COMMents?

    **Info:**
        - ``<QString>`` is the comments to be included in saved report files.
    """

    _WRAP_ARG_WITH_QUOTES = True


class SaveReport(SCPICmdWrite, SCPICmdRead):
    """The ``SAVe:REPOrt`` command.

    **Description:**
        - This command saves a report to the specified file. Supported report formats are PDF and
          MHT (web page archive file).

    **Usage:**
        - Using the ``.write(value)`` method will send the ``SAVe:REPOrt value`` command.

    **SCPI Syntax:**

    ::

        - SAVe:REPOrt <QString>

    **Info:**
        - ``<QString>`` is the complete path specification. When specifying the file name with this
          command, use the correct file extension (.pdf for PDF format, or .mht for MHT format).

    Properties:
        - ``.comments``: The ``SAVe:REPOrt:COMMents`` command.
    """

    _WRAP_ARG_WITH_QUOTES = True

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._comments = SaveReportComments(device, f"{self._cmd_syntax}:COMMents")

    @property
    def comments(self) -> SaveReportComments:
        """Return the ``SAVe:REPOrt:COMMents`` command.

        **Description:**
            - This command sets or queries the comments to be included in saved report files.

        **Usage:**
            - Using the ``.query()`` method will send the ``SAVe:REPOrt:COMMents?`` query.
            - Using the ``.verify(value)`` method will send the ``SAVe:REPOrt:COMMents?`` query and
              raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``SAVe:REPOrt:COMMents value``
              command.

        **SCPI Syntax:**

        ::

            - SAVe:REPOrt:COMMents <QString>
            - SAVe:REPOrt:COMMents?

        **Info:**
            - ``<QString>`` is the comments to be included in saved report files.
        """
        return self._comments


class SavePlotdata(SCPICmdWrite):
    """The ``SAVe:PLOTData`` command.

    **Description:**
        - Saves the plot data of the currently selected plot to a specified file. Supported file
          format is CSV.

    **Usage:**
        - Using the ``.write(value)`` method will send the ``SAVe:PLOTData value`` command.

    **SCPI Syntax:**

    ::

        - SAVe:PLOTData <Qstring>

    **Info:**
        - ``<Qstring>`` sets the file name and location used to store the plot data. When specifying
          the file name with this command, use the correct file extension (.CSV). If a file name or
          path is specified, the file is expected to be located in a directory relative to the
          current working directory (specified by ``FILESYSTEM:CWD``) unless a complete path is
          specified.
        - ``MEASUrement:ADDMEAS TIE`` To export an eye diagram plot data to a .csv file, the
          prerequisite command is.
    """


class SaveImageViewtype(SCPICmdWrite, SCPICmdRead):
    """The ``SAVe:IMAGe:VIEWTYpe`` command.

    **Description:**
        - Sets or queries the view type for saved images. Currently only FULLScreen is supported.

    **Usage:**
        - Using the ``.query()`` method will send the ``SAVe:IMAGe:VIEWTYpe?`` query.
        - Using the ``.verify(value)`` method will send the ``SAVe:IMAGe:VIEWTYpe?`` query and raise
          an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``SAVe:IMAGe:VIEWTYpe value`` command.

    **SCPI Syntax:**

    ::

        - SAVe:IMAGe:VIEWTYpe {FULLScreen}
        - SAVe:IMAGe:VIEWTYpe?

    **Info:**
        - ``FULLScreen`` sets the screen capture mode to capture the full screen.
    """


class SaveImageComposition(SCPICmdWrite, SCPICmdRead):
    """The ``SAVe:IMAGe:COMPosition`` command.

    **Description:**
        - Sets or queries the color mode for saved images (normal or inverted).

    **Usage:**
        - Using the ``.query()`` method will send the ``SAVe:IMAGe:COMPosition?`` query.
        - Using the ``.verify(value)`` method will send the ``SAVe:IMAGe:COMPosition?`` query and
          raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``SAVe:IMAGe:COMPosition value`` command.

    **SCPI Syntax:**

    ::

        - SAVe:IMAGe:COMPosition {NORMal|INVErted}
        - SAVe:IMAGe:COMPosition?

    **Info:**
        - ``NORMal`` Sets the saved screen capture to Normal colors.
        - ``INVErted`` sets the saved screen capture to Inverted colors.
    """


class SaveImage(SCPICmdWrite, SCPICmdRead):
    """The ``SAVe:IMAGe`` command.

    **Description:**
        - Saves a capture of the screen contents to the specified image file. Supported image
          formats are PNG, Windows Bitmap, and JPEG.

    **Usage:**
        - Using the ``.write(value)`` method will send the ``SAVe:IMAGe value`` command.

    **SCPI Syntax:**

    ::

        - SAVe:IMAGe <QString>

    **Info:**
        - ``<QString>`` is the file name and location used to store the image file.

    Properties:
        - ``.composition``: The ``SAVe:IMAGe:COMPosition`` command.
        - ``.viewtype``: The ``SAVe:IMAGe:VIEWTYpe`` command.
    """

    _WRAP_ARG_WITH_QUOTES = True

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._composition = SaveImageComposition(device, f"{self._cmd_syntax}:COMPosition")
        self._viewtype = SaveImageViewtype(device, f"{self._cmd_syntax}:VIEWTYpe")

    @property
    def composition(self) -> SaveImageComposition:
        """Return the ``SAVe:IMAGe:COMPosition`` command.

        **Description:**
            - Sets or queries the color mode for saved images (normal or inverted).

        **Usage:**
            - Using the ``.query()`` method will send the ``SAVe:IMAGe:COMPosition?`` query.
            - Using the ``.verify(value)`` method will send the ``SAVe:IMAGe:COMPosition?`` query
              and raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``SAVe:IMAGe:COMPosition value``
              command.

        **SCPI Syntax:**

        ::

            - SAVe:IMAGe:COMPosition {NORMal|INVErted}
            - SAVe:IMAGe:COMPosition?

        **Info:**
            - ``NORMal`` Sets the saved screen capture to Normal colors.
            - ``INVErted`` sets the saved screen capture to Inverted colors.
        """
        return self._composition

    @property
    def viewtype(self) -> SaveImageViewtype:
        """Return the ``SAVe:IMAGe:VIEWTYpe`` command.

        **Description:**
            - Sets or queries the view type for saved images. Currently only FULLScreen is
              supported.

        **Usage:**
            - Using the ``.query()`` method will send the ``SAVe:IMAGe:VIEWTYpe?`` query.
            - Using the ``.verify(value)`` method will send the ``SAVe:IMAGe:VIEWTYpe?`` query and
              raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``SAVe:IMAGe:VIEWTYpe value``
              command.

        **SCPI Syntax:**

        ::

            - SAVe:IMAGe:VIEWTYpe {FULLScreen}
            - SAVe:IMAGe:VIEWTYpe?

        **Info:**
            - ``FULLScreen`` sets the screen capture mode to capture the full screen.
        """
        return self._viewtype


class SaveEventtableSearchtable(SCPICmdWrite):
    """The ``SAVe:EVENTtable:SEARCHTable`` command.

    **Description:**
        - This command saves a search results table to the specified file.

    **Usage:**
        - Using the ``.write(value)`` method will send the ``SAVe:EVENTtable:SEARCHTable value``
          command.

    **SCPI Syntax:**

    ::

        - SAVe:EVENTtable:SEARCHTable <QString>

    **Info:**
        - ``<QString>`` is the specified file. If a file name or path is specified, the file is
          expected to be located in a directory relative to the current working directory (specified
          by ``FILESYSTEM:CWD``) unless a complete path is specified.
    """

    _WRAP_ARG_WITH_QUOTES = True


class SaveEventtableMeasurement(SCPICmdWrite):
    """The ``SAVe:EVENTtable:MEASUrement`` command.

    **Description:**
        - This command saves data (measurement) results to the specified file.

    **Usage:**
        - Using the ``.write(value)`` method will send the ``SAVe:EVENTtable:MEASUrement value``
          command.

    **SCPI Syntax:**

    ::

        - SAVe:EVENTtable:MEASUrement <QString>

    **Info:**
        - ``<QString>`` is the specified file. If a file name or path is specified, the file is
          expected to be located in a directory relative to the current working directory (specified
          by ``FILESYSTEM:CWD``) unless a complete path is specified.
    """

    _WRAP_ARG_WITH_QUOTES = True


class SaveEventtableBus(SCPICmdWrite):
    """The ``SAVe:EVENTtable:BUS`` command.

    **Description:**
        - This command saves bus results table to the specified file.

    **Usage:**
        - Using the ``.write(value)`` method will send the ``SAVe:EVENTtable:BUS value`` command.

    **SCPI Syntax:**

    ::

        - SAVe:EVENTtable:BUS <QString>

    **Info:**
        - ``<QString>`` is the specified file. If a file name or path is specified, the file is
          expected to be located in a directory relative to the current working directory (specified
          by ``FILESYSTEM:CWD``) unless a complete path is specified.
    """

    _WRAP_ARG_WITH_QUOTES = True


class SaveEventtable(SCPICmdRead):
    """The ``SAVe:EVENTtable`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``SAVe:EVENTtable?`` query.
        - Using the ``.verify(value)`` method will send the ``SAVe:EVENTtable?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.bus``: The ``SAVe:EVENTtable:BUS`` command.
        - ``.measurement``: The ``SAVe:EVENTtable:MEASUrement`` command.
        - ``.searchtable``: The ``SAVe:EVENTtable:SEARCHTable`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._bus = SaveEventtableBus(device, f"{self._cmd_syntax}:BUS")
        self._measurement = SaveEventtableMeasurement(device, f"{self._cmd_syntax}:MEASUrement")
        self._searchtable = SaveEventtableSearchtable(device, f"{self._cmd_syntax}:SEARCHTable")

    @property
    def bus(self) -> SaveEventtableBus:
        """Return the ``SAVe:EVENTtable:BUS`` command.

        **Description:**
            - This command saves bus results table to the specified file.

        **Usage:**
            - Using the ``.write(value)`` method will send the ``SAVe:EVENTtable:BUS value``
              command.

        **SCPI Syntax:**

        ::

            - SAVe:EVENTtable:BUS <QString>

        **Info:**
            - ``<QString>`` is the specified file. If a file name or path is specified, the file is
              expected to be located in a directory relative to the current working directory
              (specified by ``FILESYSTEM:CWD``) unless a complete path is specified.
        """
        return self._bus

    @property
    def measurement(self) -> SaveEventtableMeasurement:
        """Return the ``SAVe:EVENTtable:MEASUrement`` command.

        **Description:**
            - This command saves data (measurement) results to the specified file.

        **Usage:**
            - Using the ``.write(value)`` method will send the ``SAVe:EVENTtable:MEASUrement value``
              command.

        **SCPI Syntax:**

        ::

            - SAVe:EVENTtable:MEASUrement <QString>

        **Info:**
            - ``<QString>`` is the specified file. If a file name or path is specified, the file is
              expected to be located in a directory relative to the current working directory
              (specified by ``FILESYSTEM:CWD``) unless a complete path is specified.
        """
        return self._measurement

    @property
    def searchtable(self) -> SaveEventtableSearchtable:
        """Return the ``SAVe:EVENTtable:SEARCHTable`` command.

        **Description:**
            - This command saves a search results table to the specified file.

        **Usage:**
            - Using the ``.write(value)`` method will send the ``SAVe:EVENTtable:SEARCHTable value``
              command.

        **SCPI Syntax:**

        ::

            - SAVe:EVENTtable:SEARCHTable <QString>

        **Info:**
            - ``<QString>`` is the specified file. If a file name or path is specified, the file is
              expected to be located in a directory relative to the current working directory
              (specified by ``FILESYSTEM:CWD``) unless a complete path is specified.
        """
        return self._searchtable


class Save(SCPICmdRead):
    """The ``SAVe`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``SAVe?`` query.
        - Using the ``.verify(value)`` method will send the ``SAVe?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.eventtable``: The ``SAVe:EVENTtable`` command tree.
        - ``.image``: The ``SAVe:IMAGe`` command.
        - ``.plotdata``: The ``SAVe:PLOTData`` command.
        - ``.report``: The ``SAVe:REPOrt`` command.
        - ``.session``: The ``SAVe:SESsion`` command.
        - ``.setup``: The ``SAVe:SETUp`` command.
        - ``.waveform``: The ``SAVe:WAVEform`` command.
    """

    def __init__(self, device: Optional["PIDevice"] = None, cmd_syntax: str = "SAVe") -> None:
        super().__init__(device, cmd_syntax)
        self._eventtable = SaveEventtable(device, f"{self._cmd_syntax}:EVENTtable")
        self._image = SaveImage(device, f"{self._cmd_syntax}:IMAGe")
        self._plotdata = SavePlotdata(device, f"{self._cmd_syntax}:PLOTData")
        self._report = SaveReport(device, f"{self._cmd_syntax}:REPOrt")
        self._session = SaveSession(device, f"{self._cmd_syntax}:SESsion")
        self._setup = SaveSetup(device, f"{self._cmd_syntax}:SETUp")
        self._waveform = SaveWaveform(device, f"{self._cmd_syntax}:WAVEform")

    @property
    def eventtable(self) -> SaveEventtable:
        """Return the ``SAVe:EVENTtable`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``SAVe:EVENTtable?`` query.
            - Using the ``.verify(value)`` method will send the ``SAVe:EVENTtable?`` query and raise
              an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.bus``: The ``SAVe:EVENTtable:BUS`` command.
            - ``.measurement``: The ``SAVe:EVENTtable:MEASUrement`` command.
            - ``.searchtable``: The ``SAVe:EVENTtable:SEARCHTable`` command.
        """
        return self._eventtable

    @property
    def image(self) -> SaveImage:
        """Return the ``SAVe:IMAGe`` command.

        **Description:**
            - Saves a capture of the screen contents to the specified image file. Supported image
              formats are PNG, Windows Bitmap, and JPEG.

        **Usage:**
            - Using the ``.write(value)`` method will send the ``SAVe:IMAGe value`` command.

        **SCPI Syntax:**

        ::

            - SAVe:IMAGe <QString>

        **Info:**
            - ``<QString>`` is the file name and location used to store the image file.

        Sub-properties:
            - ``.composition``: The ``SAVe:IMAGe:COMPosition`` command.
            - ``.viewtype``: The ``SAVe:IMAGe:VIEWTYpe`` command.
        """
        return self._image

    @property
    def plotdata(self) -> SavePlotdata:
        """Return the ``SAVe:PLOTData`` command.

        **Description:**
            - Saves the plot data of the currently selected plot to a specified file. Supported file
              format is CSV.

        **Usage:**
            - Using the ``.write(value)`` method will send the ``SAVe:PLOTData value`` command.

        **SCPI Syntax:**

        ::

            - SAVe:PLOTData <Qstring>

        **Info:**
            - ``<Qstring>`` sets the file name and location used to store the plot data. When
              specifying the file name with this command, use the correct file extension (.CSV). If
              a file name or path is specified, the file is expected to be located in a directory
              relative to the current working directory (specified by ``FILESYSTEM:CWD``) unless a
              complete path is specified.
            - ``MEASUrement:ADDMEAS TIE`` To export an eye diagram plot data to a .csv file, the
              prerequisite command is.
        """
        return self._plotdata

    @property
    def report(self) -> SaveReport:
        """Return the ``SAVe:REPOrt`` command.

        **Description:**
            - This command saves a report to the specified file. Supported report formats are PDF
              and MHT (web page archive file).

        **Usage:**
            - Using the ``.write(value)`` method will send the ``SAVe:REPOrt value`` command.

        **SCPI Syntax:**

        ::

            - SAVe:REPOrt <QString>

        **Info:**
            - ``<QString>`` is the complete path specification. When specifying the file name with
              this command, use the correct file extension (.pdf for PDF format, or .mht for MHT
              format).

        Sub-properties:
            - ``.comments``: The ``SAVe:REPOrt:COMMents`` command.
        """
        return self._report

    @property
    def session(self) -> SaveSession:
        """Return the ``SAVe:SESsion`` command.

        **Description:**
            - Saves the state of the instrument, including reference waveforms, to a saved session
              file.

        **Usage:**
            - Using the ``.write(value)`` method will send the ``SAVe:SESsion value`` command.

        **SCPI Syntax:**

        ::

            - SAVe:SESsion <QString>

        **Info:**
            - ``<QString>`` is the file path that specifies the location to save the specified
              instrument session file. If a file name or path is specified, the file is expected to
              be located in a directory relative to the current working directory (specified by.
        """
        return self._session

    @property
    def setup(self) -> SaveSetup:
        """Return the ``SAVe:SETUp`` command.

        **Description:**
            - Saves the current instrument state to the specified file.

        **Usage:**
            - Using the ``.write(value)`` method will send the ``SAVe:SETUp value`` command.

        **SCPI Syntax:**

        ::

            - SAVe:SETUp <QString>

        **Info:**
            - ``<QString>`` is a quoted string that is the complete path specification. If a file
              name or path is specified, the file is expected to be located in a directory relative
              to the current working directory (specified by ``FILESYSTEM:CWD``) unless a complete
              path is specified.

        Sub-properties:
            - ``.includerefs``: The ``SAVe:SETUp:INCLUDEREFs`` command.
        """
        return self._setup

    @property
    def waveform(self) -> SaveWaveform:
        """Return the ``SAVe:WAVEform`` command.

        **Description:**
            - This command saves the specified waveform(s) to the specified destination file.

        **Usage:**
            - Using the ``.write(value)`` method will send the ``SAVe:WAVEform value`` command.

        **SCPI Syntax:**

        ::

            - SAVe:WAVEform {CH<x>[_DALL|_SV_NORMal|_SV_AVErage|_SV_MAXHold| _SV_MINHold|_MAG_VS_TIME|_FREQ_VS_TIME| _PHASE_VS_TIME _SV_BASEBAND_IQ]|MATH<x>|REF<x>|ALL| },<QString>

        **Info:**
            - ``<x>`` is the number of the analog channel (CH<x>), math (MATH<x>), or reference
              (REF<x>) waveform source used to save the waveform data.
            - ``_DALL`` saves the digital channel waveform data of the specified channel.
            - ``_SV_NORMal`` saves the Normal Spectrum view waveform of the specified channel.
            - ``_SV_AVErage`` saves the Average Spectrum view waveform of the specified channel.
            - ``_SV_MAXHold`` saves the Maximum Hold Spectrum view waveform of the specified
              channel.
            - ``_SV_MINHold`` saves the Minimum Hold Spectrum view waveform of the specified
              channel.
            - ``_MAG_VS_TIME`` saves the Magnitude vs.
            - ``_FREQ_VS_TIME`` saves the Freuency vs.
            - ``_PHASE_VS_TIME`` saves the Phase vs.
            - ``_SV_BASEBAND_IQ`` saves the baseband I & Q data of the specified channel.
            - ``ALL`` saves all displayed analog, math, and reference waveforms to individual files.
            - ``<Qstring>`` is a quoted string that defines the path and file name to use to save
              the specified file, in the format '[<path>]<filename.
            - ``<path>`` uses the form '<drive>/<dir>.
            - ``<filename>`` sets the file name to use to create the file.
            - ``<.ext>`` sets the file format to which to save the data.

        Sub-properties:
            - ``.gating``: The ``SAVe:WAVEform:GATing`` command.
            - ``.sourcelist``: The ``SAVe:WAVEform:SOURCELIst`` command.
        """  # noqa: E501
        return self._waveform



"""SMU Model 2611B device driver module."""
from tm_devices.commands import SMU2611BMixin
from tm_devices.drivers.pi.source_measure_units.smu2600.smu2600b import SMU2600B


class SMU2611B(SMU2611BMixin, SMU2600B):
    """SMU2611B device driver."""



# pylint: disable=too-many-lines
"""The mask commands module.

These commands are used in the following models:
MSO2

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Commands and Queries:

::

    - MASK:DELete 'MASK<x>'
    - MASK:MASK<x>:COUNT:HITS?
    - MASK:MASK<x>:COUNT?
    - MASK:MASK<x>:DEFinedby {SEGments|TOLerances}
    - MASK:MASK<x>:DEFinedby?
    - MASK:MASK<x>:DISplay {ON|OFF}
    - MASK:MASK<x>:DISplay?
    - MASK:MASK<x>:LIST?
    - MASK:MASK<x>:SEG<x>:POINTS
    - MASK:MASK<x>:SEG<x>:POINTS?
    - MASK:MASK<x>:SEG<x>COUNT:HITS?
    - MASK:MASK<x>:SOUrce {CH<x>|REF<x>|MATH<x>|RFvsTime}
    - MASK:MASK<x>:SOUrce?
    - MASK:MASK<x>:TESt:STATE {ON|OFF}
    - MASK:MASK<x>:TESt:STATE?
    - MASK:MASK<x>:TESt:STATUS?
    - MASK:MASK<x>:TESt:THReshold <NR1>
    - MASK:MASK<x>:TESt:THReshold?
    - MASK:MASK<x>:TOLerance:HORizontal <NR3>
    - MASK:MASK<x>:TOLerance:HORizontal?
    - MASK:MASK<x>:TOLerance:UPDatenow
    - MASK:MASK<x>:TOLerance:VERTical <NR3>
    - MASK:MASK<x>:TOLerance:VERTical?
    - MASK:TESt:WAVEforms <NR1>
    - MASK:TESt:WAVEforms?
"""
from typing import Dict, Optional, TYPE_CHECKING

from .._helpers import (
    DefaultDictPassKeyToFactory,
    SCPICmdRead,
    SCPICmdWrite,
    SCPICmdWriteNoArguments,
    ValidatedDynamicNumberCmd,
)

if TYPE_CHECKING:
    from tm_devices.drivers.pi.pi_device import PIDevice


class MaskTestWaveforms(SCPICmdWrite, SCPICmdRead):
    """The ``MASK:TESt:WAVEforms`` command.

    **Description:**
        - This command sets or queries the number of waveform acquisitions to test during mask
          testing. The number of waveforms applies to all mask tests.

    **Usage:**
        - Using the ``.query()`` method will send the ``MASK:TESt:WAVEforms?`` query.
        - Using the ``.verify(value)`` method will send the ``MASK:TESt:WAVEforms?`` query and raise
          an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``MASK:TESt:WAVEforms value`` command.

    **SCPI Syntax:**

    ::

        - MASK:TESt:WAVEforms <NR1>
        - MASK:TESt:WAVEforms?

    **Info:**
        - ``<NR1>`` specifies the number of waveform acquisitions.
    """


class MaskTest(SCPICmdRead):
    """The ``MASK:TESt`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``MASK:TESt?`` query.
        - Using the ``.verify(value)`` method will send the ``MASK:TESt?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.waveforms``: The ``MASK:TESt:WAVEforms`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._waveforms = MaskTestWaveforms(device, f"{self._cmd_syntax}:WAVEforms")

    @property
    def waveforms(self) -> MaskTestWaveforms:
        """Return the ``MASK:TESt:WAVEforms`` command.

        **Description:**
            - This command sets or queries the number of waveform acquisitions to test during mask
              testing. The number of waveforms applies to all mask tests.

        **Usage:**
            - Using the ``.query()`` method will send the ``MASK:TESt:WAVEforms?`` query.
            - Using the ``.verify(value)`` method will send the ``MASK:TESt:WAVEforms?`` query and
              raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``MASK:TESt:WAVEforms value``
              command.

        **SCPI Syntax:**

        ::

            - MASK:TESt:WAVEforms <NR1>
            - MASK:TESt:WAVEforms?

        **Info:**
            - ``<NR1>`` specifies the number of waveform acquisitions.
        """
        return self._waveforms


class MaskMaskItemToleranceVertical(SCPICmdWrite, SCPICmdRead):
    """The ``MASK:MASK<x>:TOLerance:VERTical`` command.

    **Description:**
        - This command sets or queries the mask vertical tolerance.

    **Usage:**
        - Using the ``.query()`` method will send the ``MASK:MASK<x>:TOLerance:VERTical?`` query.
        - Using the ``.verify(value)`` method will send the ``MASK:MASK<x>:TOLerance:VERTical?``
          query and raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``MASK:MASK<x>:TOLerance:VERTical value``
          command.

    **SCPI Syntax:**

    ::

        - MASK:MASK<x>:TOLerance:VERTical <NR3>
        - MASK:MASK<x>:TOLerance:VERTical?

    **Info:**
        - ``MASK<x>`` specifies the mask number.
        - ``<NR3>`` is the tolerance in units of graticule divisions. The maximum is 1 division.
    """


class MaskMaskItemToleranceUpdatenow(SCPICmdWriteNoArguments):
    """The ``MASK:MASK<x>:TOLerance:UPDatenow`` command.

    **Description:**
        - This command causes the tolerance mask to be recalculated with the current horizontal and
          vertical tolerances.

    **Usage:**
        - Using the ``.write()`` method will send the ``MASK:MASK<x>:TOLerance:UPDatenow`` command.

    **SCPI Syntax:**

    ::

        - MASK:MASK<x>:TOLerance:UPDatenow

    **Info:**
        - ``MASK<x>`` specifies the mask number.
    """


class MaskMaskItemToleranceHorizontal(SCPICmdWrite, SCPICmdRead):
    """The ``MASK:MASK<x>:TOLerance:HORizontal`` command.

    **Description:**
        - This command sets or queries the mask horizontal tolerance.

    **Usage:**
        - Using the ``.query()`` method will send the ``MASK:MASK<x>:TOLerance:HORizontal?`` query.
        - Using the ``.verify(value)`` method will send the ``MASK:MASK<x>:TOLerance:HORizontal?``
          query and raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the
          ``MASK:MASK<x>:TOLerance:HORizontal value`` command.

    **SCPI Syntax:**

    ::

        - MASK:MASK<x>:TOLerance:HORizontal <NR3>
        - MASK:MASK<x>:TOLerance:HORizontal?

    **Info:**
        - ``MASK<x>`` specifies the mask number.
        - ``<NR3>`` is the tolerance in units of graticule divisions. The maximum is 1 division.
    """


class MaskMaskItemTolerance(SCPICmdRead):
    """The ``MASK:MASK<x>:TOLerance`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``MASK:MASK<x>:TOLerance?`` query.
        - Using the ``.verify(value)`` method will send the ``MASK:MASK<x>:TOLerance?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    **Info:**
        - ``MASK<x>`` specifies the mask number.

    Properties:
        - ``.horizontal``: The ``MASK:MASK<x>:TOLerance:HORizontal`` command.
        - ``.updatenow``: The ``MASK:MASK<x>:TOLerance:UPDatenow`` command.
        - ``.vertical``: The ``MASK:MASK<x>:TOLerance:VERTical`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._horizontal = MaskMaskItemToleranceHorizontal(device, f"{self._cmd_syntax}:HORizontal")
        self._updatenow = MaskMaskItemToleranceUpdatenow(device, f"{self._cmd_syntax}:UPDatenow")
        self._vertical = MaskMaskItemToleranceVertical(device, f"{self._cmd_syntax}:VERTical")

    @property
    def horizontal(self) -> MaskMaskItemToleranceHorizontal:
        """Return the ``MASK:MASK<x>:TOLerance:HORizontal`` command.

        **Description:**
            - This command sets or queries the mask horizontal tolerance.

        **Usage:**
            - Using the ``.query()`` method will send the ``MASK:MASK<x>:TOLerance:HORizontal?``
              query.
            - Using the ``.verify(value)`` method will send the
              ``MASK:MASK<x>:TOLerance:HORizontal?`` query and raise an AssertionError if the
              returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the
              ``MASK:MASK<x>:TOLerance:HORizontal value`` command.

        **SCPI Syntax:**

        ::

            - MASK:MASK<x>:TOLerance:HORizontal <NR3>
            - MASK:MASK<x>:TOLerance:HORizontal?

        **Info:**
            - ``MASK<x>`` specifies the mask number.
            - ``<NR3>`` is the tolerance in units of graticule divisions. The maximum is 1 division.
        """
        return self._horizontal

    @property
    def updatenow(self) -> MaskMaskItemToleranceUpdatenow:
        """Return the ``MASK:MASK<x>:TOLerance:UPDatenow`` command.

        **Description:**
            - This command causes the tolerance mask to be recalculated with the current horizontal
              and vertical tolerances.

        **Usage:**
            - Using the ``.write()`` method will send the ``MASK:MASK<x>:TOLerance:UPDatenow``
              command.

        **SCPI Syntax:**

        ::

            - MASK:MASK<x>:TOLerance:UPDatenow

        **Info:**
            - ``MASK<x>`` specifies the mask number.
        """
        return self._updatenow

    @property
    def vertical(self) -> MaskMaskItemToleranceVertical:
        """Return the ``MASK:MASK<x>:TOLerance:VERTical`` command.

        **Description:**
            - This command sets or queries the mask vertical tolerance.

        **Usage:**
            - Using the ``.query()`` method will send the ``MASK:MASK<x>:TOLerance:VERTical?``
              query.
            - Using the ``.verify(value)`` method will send the ``MASK:MASK<x>:TOLerance:VERTical?``
              query and raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the
              ``MASK:MASK<x>:TOLerance:VERTical value`` command.

        **SCPI Syntax:**

        ::

            - MASK:MASK<x>:TOLerance:VERTical <NR3>
            - MASK:MASK<x>:TOLerance:VERTical?

        **Info:**
            - ``MASK<x>`` specifies the mask number.
            - ``<NR3>`` is the tolerance in units of graticule divisions. The maximum is 1 division.
        """
        return self._vertical


class MaskMaskItemTestThreshold(SCPICmdWrite, SCPICmdRead):
    """The ``MASK:MASK<x>:TESt:THReshold`` command.

    **Description:**
        - This command sets or queries the number of waveform violations needed for the specified
          mask test to change from PASS to FAIL.

    **Usage:**
        - Using the ``.query()`` method will send the ``MASK:MASK<x>:TESt:THReshold?`` query.
        - Using the ``.verify(value)`` method will send the ``MASK:MASK<x>:TESt:THReshold?`` query
          and raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``MASK:MASK<x>:TESt:THReshold value``
          command.

    **SCPI Syntax:**

    ::

        - MASK:MASK<x>:TESt:THReshold <NR1>
        - MASK:MASK<x>:TESt:THReshold?

    **Info:**
        - ``MASK<x>`` specifies the mask test.
        - ``<NR1>`` specifies the threshold value.
    """


class MaskMaskItemTestStatus(SCPICmdRead):
    """The ``MASK:MASK<x>:TESt:STATUS`` command.

    **Description:**
        - This command returns the status of the specified mask test.

    **Usage:**
        - Using the ``.query()`` method will send the ``MASK:MASK<x>:TESt:STATUS?`` query.
        - Using the ``.verify(value)`` method will send the ``MASK:MASK<x>:TESt:STATUS?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - MASK:MASK<x>:TESt:STATUS?

    **Info:**
        - ``MASK<x>`` specifies the mask test.
    """


class MaskMaskItemTestState(SCPICmdWrite, SCPICmdRead):
    """The ``MASK:MASK<x>:TESt:STATE`` command.

    **Description:**
        - This command sets or queries the state of the specified mask test.

    **Usage:**
        - Using the ``.query()`` method will send the ``MASK:MASK<x>:TESt:STATE?`` query.
        - Using the ``.verify(value)`` method will send the ``MASK:MASK<x>:TESt:STATE?`` query and
          raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``MASK:MASK<x>:TESt:STATE value``
          command.

    **SCPI Syntax:**

    ::

        - MASK:MASK<x>:TESt:STATE {ON|OFF}
        - MASK:MASK<x>:TESt:STATE?

    **Info:**
        - ``MASK<x>`` specifies the mask test.
        - ``ON`` sets the mask test state to ON. When the state is ON the Pass/Fail status and hit
          count information are reset and the mask test is started.
        - ``OFF`` sets the mask test state to OFF. When the mask test completes the state is set to
          OFF.
    """


class MaskMaskItemTest(SCPICmdRead):
    """The ``MASK:MASK<x>:TESt`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``MASK:MASK<x>:TESt?`` query.
        - Using the ``.verify(value)`` method will send the ``MASK:MASK<x>:TESt?`` query and raise
          an AssertionError if the returned value does not match ``value``.

    **Info:**
        - ``MASK<x>`` specifies the mask test.

    Properties:
        - ``.state``: The ``MASK:MASK<x>:TESt:STATE`` command.
        - ``.status``: The ``MASK:MASK<x>:TESt:STATUS`` command.
        - ``.threshold``: The ``MASK:MASK<x>:TESt:THReshold`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._state = MaskMaskItemTestState(device, f"{self._cmd_syntax}:STATE")
        self._status = MaskMaskItemTestStatus(device, f"{self._cmd_syntax}:STATUS")
        self._threshold = MaskMaskItemTestThreshold(device, f"{self._cmd_syntax}:THReshold")

    @property
    def state(self) -> MaskMaskItemTestState:
        """Return the ``MASK:MASK<x>:TESt:STATE`` command.

        **Description:**
            - This command sets or queries the state of the specified mask test.

        **Usage:**
            - Using the ``.query()`` method will send the ``MASK:MASK<x>:TESt:STATE?`` query.
            - Using the ``.verify(value)`` method will send the ``MASK:MASK<x>:TESt:STATE?`` query
              and raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``MASK:MASK<x>:TESt:STATE value``
              command.

        **SCPI Syntax:**

        ::

            - MASK:MASK<x>:TESt:STATE {ON|OFF}
            - MASK:MASK<x>:TESt:STATE?

        **Info:**
            - ``MASK<x>`` specifies the mask test.
            - ``ON`` sets the mask test state to ON. When the state is ON the Pass/Fail status and
              hit count information are reset and the mask test is started.
            - ``OFF`` sets the mask test state to OFF. When the mask test completes the state is set
              to OFF.
        """
        return self._state

    @property
    def status(self) -> MaskMaskItemTestStatus:
        """Return the ``MASK:MASK<x>:TESt:STATUS`` command.

        **Description:**
            - This command returns the status of the specified mask test.

        **Usage:**
            - Using the ``.query()`` method will send the ``MASK:MASK<x>:TESt:STATUS?`` query.
            - Using the ``.verify(value)`` method will send the ``MASK:MASK<x>:TESt:STATUS?`` query
              and raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - MASK:MASK<x>:TESt:STATUS?

        **Info:**
            - ``MASK<x>`` specifies the mask test.
        """
        return self._status

    @property
    def threshold(self) -> MaskMaskItemTestThreshold:
        """Return the ``MASK:MASK<x>:TESt:THReshold`` command.

        **Description:**
            - This command sets or queries the number of waveform violations needed for the
              specified mask test to change from PASS to FAIL.

        **Usage:**
            - Using the ``.query()`` method will send the ``MASK:MASK<x>:TESt:THReshold?`` query.
            - Using the ``.verify(value)`` method will send the ``MASK:MASK<x>:TESt:THReshold?``
              query and raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``MASK:MASK<x>:TESt:THReshold value``
              command.

        **SCPI Syntax:**

        ::

            - MASK:MASK<x>:TESt:THReshold <NR1>
            - MASK:MASK<x>:TESt:THReshold?

        **Info:**
            - ``MASK<x>`` specifies the mask test.
            - ``<NR1>`` specifies the threshold value.
        """
        return self._threshold


class MaskMaskItemSource(SCPICmdWrite, SCPICmdRead):
    """The ``MASK:MASK<x>:SOUrce`` command.

    **Description:**
        - This command sets or queries analog source for the specified mask test.

    **Usage:**
        - Using the ``.query()`` method will send the ``MASK:MASK<x>:SOUrce?`` query.
        - Using the ``.verify(value)`` method will send the ``MASK:MASK<x>:SOUrce?`` query and raise
          an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``MASK:MASK<x>:SOUrce value`` command.

    **SCPI Syntax:**

    ::

        - MASK:MASK<x>:SOUrce {CH<x>|REF<x>|MATH<x>|RFvsTime}
        - MASK:MASK<x>:SOUrce?

    **Info:**
        - ``MASK<x>`` specifies the mask test.
        - ``CH<x>`` specifies an analog channel as source.
        - ``MATH<x>`` specifies a math channel as source.
        - ``REF<x>`` specifies a reference waveform as the source.
        - ``RFvsTime`` specifies a RF vs Time as the source.
    """


class MaskMaskItemSegcountItemHits(SCPICmdRead):
    """The ``MASK:MASK<x>:SEG<x>COUNT:HITS`` command.

    **Description:**
        - The command returns the total number of mask hits in the specified mask segment of the
          specified mask test.

    **Usage:**
        - Using the ``.query()`` method will send the ``MASK:MASK<x>:SEG<x>COUNT:HITS?`` query.
        - Using the ``.verify(value)`` method will send the ``MASK:MASK<x>:SEG<x>COUNT:HITS?`` query
          and raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - MASK:MASK<x>:SEG<x>COUNT:HITS?

    **Info:**
        - ``MASK<x>`` specifies the mask test.
        - ``SEG<x>`` specifies the mask segment.
    """


class MaskMaskItemSegcountItem(ValidatedDynamicNumberCmd, SCPICmdRead):
    """The ``MASK:MASK<x>:SEG<x>COUNT`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``MASK:MASK<x>:SEG<x>COUNT?`` query.
        - Using the ``.verify(value)`` method will send the ``MASK:MASK<x>:SEG<x>COUNT?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    **Info:**
        - ``MASK<x>`` specifies the mask test.
        - ``SEG<x>`` specifies the mask segment.

    Properties:
        - ``.hits``: The ``MASK:MASK<x>:SEG<x>COUNT:HITS`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._hits = MaskMaskItemSegcountItemHits(device, f"{self._cmd_syntax}:HITS")

    @property
    def hits(self) -> MaskMaskItemSegcountItemHits:
        """Return the ``MASK:MASK<x>:SEG<x>COUNT:HITS`` command.

        **Description:**
            - The command returns the total number of mask hits in the specified mask segment of the
              specified mask test.

        **Usage:**
            - Using the ``.query()`` method will send the ``MASK:MASK<x>:SEG<x>COUNT:HITS?`` query.
            - Using the ``.verify(value)`` method will send the ``MASK:MASK<x>:SEG<x>COUNT:HITS?``
              query and raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - MASK:MASK<x>:SEG<x>COUNT:HITS?

        **Info:**
            - ``MASK<x>`` specifies the mask test.
            - ``SEG<x>`` specifies the mask segment.
        """
        return self._hits


class MaskMaskItemSegItemPoints(SCPICmdWriteNoArguments, SCPICmdRead):
    """The ``MASK:MASK<x>:SEG<x>:POINTS`` command.

    **Description:**
        - This command sets or queries the X/Y coordinates of all points in the designated mask
          segment. Mask vertices are in time/volts (currently limited to 1024 characters). The set
          form defines new points in the mask, replacing any existing points.

    **Usage:**
        - Using the ``.query()`` method will send the ``MASK:MASK<x>:SEG<x>:POINTS?`` query.
        - Using the ``.verify(value)`` method will send the ``MASK:MASK<x>:SEG<x>:POINTS?`` query
          and raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write()`` method will send the ``MASK:MASK<x>:SEG<x>:POINTS`` command.

    **SCPI Syntax:**

    ::

        - MASK:MASK<x>:SEG<x>:POINTS
        - MASK:MASK<x>:SEG<x>:POINTS?

    **Info:**
        - ``MASK<x>`` specifies the mask test.
        - ``SEG<x>`` specifies the mask segment.
    """


class MaskMaskItemSegItem(ValidatedDynamicNumberCmd, SCPICmdRead):
    """The ``MASK:MASK<x>:SEG<x>`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``MASK:MASK<x>:SEG<x>?`` query.
        - Using the ``.verify(value)`` method will send the ``MASK:MASK<x>:SEG<x>?`` query and raise
          an AssertionError if the returned value does not match ``value``.

    **Info:**
        - ``MASK<x>`` specifies the mask test.
        - ``SEG<x>`` specifies the mask segment.

    Properties:
        - ``.points``: The ``MASK:MASK<x>:SEG<x>:POINTS`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._points = MaskMaskItemSegItemPoints(device, f"{self._cmd_syntax}:POINTS")

    @property
    def points(self) -> MaskMaskItemSegItemPoints:
        """Return the ``MASK:MASK<x>:SEG<x>:POINTS`` command.

        **Description:**
            - This command sets or queries the X/Y coordinates of all points in the designated mask
              segment. Mask vertices are in time/volts (currently limited to 1024 characters). The
              set form defines new points in the mask, replacing any existing points.

        **Usage:**
            - Using the ``.query()`` method will send the ``MASK:MASK<x>:SEG<x>:POINTS?`` query.
            - Using the ``.verify(value)`` method will send the ``MASK:MASK<x>:SEG<x>:POINTS?``
              query and raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write()`` method will send the ``MASK:MASK<x>:SEG<x>:POINTS`` command.

        **SCPI Syntax:**

        ::

            - MASK:MASK<x>:SEG<x>:POINTS
            - MASK:MASK<x>:SEG<x>:POINTS?

        **Info:**
            - ``MASK<x>`` specifies the mask test.
            - ``SEG<x>`` specifies the mask segment.
        """
        return self._points


class MaskMaskItemList(SCPICmdRead):
    """The ``MASK:MASK<x>:LIST`` command.

    **Description:**
        - This command queries the list of segments in the mask used by the specified mask test.

    **Usage:**
        - Using the ``.query()`` method will send the ``MASK:MASK<x>:LIST?`` query.
        - Using the ``.verify(value)`` method will send the ``MASK:MASK<x>:LIST?`` query and raise
          an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - MASK:MASK<x>:LIST?

    **Info:**
        - ``MASK<x>`` specifies the mask test.
    """


class MaskMaskItemDisplay(SCPICmdWrite, SCPICmdRead):
    """The ``MASK:MASK<x>:DISplay`` command.

    **Description:**
        - This command sets or queries the display state of the mask used for the specified mask
          test.

    **Usage:**
        - Using the ``.query()`` method will send the ``MASK:MASK<x>:DISplay?`` query.
        - Using the ``.verify(value)`` method will send the ``MASK:MASK<x>:DISplay?`` query and
          raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``MASK:MASK<x>:DISplay value`` command.

    **SCPI Syntax:**

    ::

        - MASK:MASK<x>:DISplay {ON|OFF}
        - MASK:MASK<x>:DISplay?

    **Info:**
        - ``MASK<x>`` specifies the mask test.
        - ``ON`` sets the display state of the specified mask to on.
        - ``OFF`` sets the display state of the specified mask to off.
    """


class MaskMaskItemDefinedby(SCPICmdWrite, SCPICmdRead):
    """The ``MASK:MASK<x>:DEFinedby`` command.

    **Description:**
        - This command sets or queries whether the specified mask is defined by segments or
          tolerances. Segment masks are defined by one or more polygons. Tolerance masks are defined
          by specified horizontal and vertical tolerances around the mask source.

    **Usage:**
        - Using the ``.query()`` method will send the ``MASK:MASK<x>:DEFinedby?`` query.
        - Using the ``.verify(value)`` method will send the ``MASK:MASK<x>:DEFinedby?`` query and
          raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``MASK:MASK<x>:DEFinedby value`` command.

    **SCPI Syntax:**

    ::

        - MASK:MASK<x>:DEFinedby {SEGments|TOLerances}
        - MASK:MASK<x>:DEFinedby?

    **Info:**
        - ``MASK<x>`` specifies the mask number.
        - ``SEGments`` defines the mask by segments.
        - ``TOLerances`` defines the mask by horizontal and vertical tolerances around mask source.
    """


class MaskMaskItemCountHits(SCPICmdRead):
    """The ``MASK:MASK<x>:COUNT:HITS`` command.

    **Description:**
        - This command returns the total number of mask hits in all mask segments for the specified
          mask test.

    **Usage:**
        - Using the ``.query()`` method will send the ``MASK:MASK<x>:COUNT:HITS?`` query.
        - Using the ``.verify(value)`` method will send the ``MASK:MASK<x>:COUNT:HITS?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - MASK:MASK<x>:COUNT:HITS?

    **Info:**
        - ``MASK<x>`` specifies the mask test.
    """


class MaskMaskItemCount(SCPICmdRead):
    """The ``MASK:MASK<x>:COUNT`` command.

    **Description:**
        - This command returns the total number of mask hits in all segments and the number of mask
          hits in each individual mask segment for the specified mask test.

    **Usage:**
        - Using the ``.query()`` method will send the ``MASK:MASK<x>:COUNT?`` query.
        - Using the ``.verify(value)`` method will send the ``MASK:MASK<x>:COUNT?`` query and raise
          an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - MASK:MASK<x>:COUNT?

    **Info:**
        - ``MASK<x>`` specifies the mask test.

    Properties:
        - ``.hits``: The ``MASK:MASK<x>:COUNT:HITS`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._hits = MaskMaskItemCountHits(device, f"{self._cmd_syntax}:HITS")

    @property
    def hits(self) -> MaskMaskItemCountHits:
        """Return the ``MASK:MASK<x>:COUNT:HITS`` command.

        **Description:**
            - This command returns the total number of mask hits in all mask segments for the
              specified mask test.

        **Usage:**
            - Using the ``.query()`` method will send the ``MASK:MASK<x>:COUNT:HITS?`` query.
            - Using the ``.verify(value)`` method will send the ``MASK:MASK<x>:COUNT:HITS?`` query
              and raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - MASK:MASK<x>:COUNT:HITS?

        **Info:**
            - ``MASK<x>`` specifies the mask test.
        """
        return self._hits


#  pylint: disable=too-many-instance-attributes
class MaskMaskItem(ValidatedDynamicNumberCmd, SCPICmdRead):
    """The ``MASK:MASK<x>`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``MASK:MASK<x>?`` query.
        - Using the ``.verify(value)`` method will send the ``MASK:MASK<x>?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    **Info:**
        - ``MASK<x>`` specifies the mask test.

    Properties:
        - ``.count``: The ``MASK:MASK<x>:COUNT`` command.
        - ``.definedby``: The ``MASK:MASK<x>:DEFinedby`` command.
        - ``.display``: The ``MASK:MASK<x>:DISplay`` command.
        - ``.list``: The ``MASK:MASK<x>:LIST`` command.
        - ``.seg``: The ``MASK:MASK<x>:SEG<x>`` command tree.
        - ``.segcount``: The ``MASK:MASK<x>:SEG<x>COUNT`` command tree.
        - ``.source``: The ``MASK:MASK<x>:SOUrce`` command.
        - ``.test``: The ``MASK:MASK<x>:TESt`` command tree.
        - ``.tolerance``: The ``MASK:MASK<x>:TOLerance`` command tree.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._count = MaskMaskItemCount(device, f"{self._cmd_syntax}:COUNT")
        self._definedby = MaskMaskItemDefinedby(device, f"{self._cmd_syntax}:DEFinedby")
        self._display = MaskMaskItemDisplay(device, f"{self._cmd_syntax}:DISplay")
        self._list = MaskMaskItemList(device, f"{self._cmd_syntax}:LIST")
        self._seg: Dict[int, MaskMaskItemSegItem] = DefaultDictPassKeyToFactory(
            lambda x: MaskMaskItemSegItem(device, f"{self._cmd_syntax}:SEG{x}")
        )
        self._segcount: Dict[int, MaskMaskItemSegcountItem] = DefaultDictPassKeyToFactory(
            lambda x: MaskMaskItemSegcountItem(device, f"{self._cmd_syntax}:SEG{x}COUNT")
        )
        self._source = MaskMaskItemSource(device, f"{self._cmd_syntax}:SOUrce")
        self._test = MaskMaskItemTest(device, f"{self._cmd_syntax}:TESt")
        self._tolerance = MaskMaskItemTolerance(device, f"{self._cmd_syntax}:TOLerance")

    @property
    def count(self) -> MaskMaskItemCount:
        """Return the ``MASK:MASK<x>:COUNT`` command.

        **Description:**
            - This command returns the total number of mask hits in all segments and the number of
              mask hits in each individual mask segment for the specified mask test.

        **Usage:**
            - Using the ``.query()`` method will send the ``MASK:MASK<x>:COUNT?`` query.
            - Using the ``.verify(value)`` method will send the ``MASK:MASK<x>:COUNT?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - MASK:MASK<x>:COUNT?

        **Info:**
            - ``MASK<x>`` specifies the mask test.

        Sub-properties:
            - ``.hits``: The ``MASK:MASK<x>:COUNT:HITS`` command.
        """
        return self._count

    @property
    def definedby(self) -> MaskMaskItemDefinedby:
        """Return the ``MASK:MASK<x>:DEFinedby`` command.

        **Description:**
            - This command sets or queries whether the specified mask is defined by segments or
              tolerances. Segment masks are defined by one or more polygons. Tolerance masks are
              defined by specified horizontal and vertical tolerances around the mask source.

        **Usage:**
            - Using the ``.query()`` method will send the ``MASK:MASK<x>:DEFinedby?`` query.
            - Using the ``.verify(value)`` method will send the ``MASK:MASK<x>:DEFinedby?`` query
              and raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``MASK:MASK<x>:DEFinedby value``
              command.

        **SCPI Syntax:**

        ::

            - MASK:MASK<x>:DEFinedby {SEGments|TOLerances}
            - MASK:MASK<x>:DEFinedby?

        **Info:**
            - ``MASK<x>`` specifies the mask number.
            - ``SEGments`` defines the mask by segments.
            - ``TOLerances`` defines the mask by horizontal and vertical tolerances around mask
              source.
        """
        return self._definedby

    @property
    def display(self) -> MaskMaskItemDisplay:
        """Return the ``MASK:MASK<x>:DISplay`` command.

        **Description:**
            - This command sets or queries the display state of the mask used for the specified mask
              test.

        **Usage:**
            - Using the ``.query()`` method will send the ``MASK:MASK<x>:DISplay?`` query.
            - Using the ``.verify(value)`` method will send the ``MASK:MASK<x>:DISplay?`` query and
              raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``MASK:MASK<x>:DISplay value``
              command.

        **SCPI Syntax:**

        ::

            - MASK:MASK<x>:DISplay {ON|OFF}
            - MASK:MASK<x>:DISplay?

        **Info:**
            - ``MASK<x>`` specifies the mask test.
            - ``ON`` sets the display state of the specified mask to on.
            - ``OFF`` sets the display state of the specified mask to off.
        """
        return self._display

    @property
    def list(self) -> MaskMaskItemList:
        """Return the ``MASK:MASK<x>:LIST`` command.

        **Description:**
            - This command queries the list of segments in the mask used by the specified mask test.

        **Usage:**
            - Using the ``.query()`` method will send the ``MASK:MASK<x>:LIST?`` query.
            - Using the ``.verify(value)`` method will send the ``MASK:MASK<x>:LIST?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - MASK:MASK<x>:LIST?

        **Info:**
            - ``MASK<x>`` specifies the mask test.
        """
        return self._list

    @property
    def seg(self) -> Dict[int, MaskMaskItemSegItem]:
        """Return the ``MASK:MASK<x>:SEG<x>`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``MASK:MASK<x>:SEG<x>?`` query.
            - Using the ``.verify(value)`` method will send the ``MASK:MASK<x>:SEG<x>?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        **Info:**
            - ``MASK<x>`` specifies the mask test.
            - ``SEG<x>`` specifies the mask segment.

        Sub-properties:
            - ``.points``: The ``MASK:MASK<x>:SEG<x>:POINTS`` command.
        """
        return self._seg

    @property
    def segcount(self) -> Dict[int, MaskMaskItemSegcountItem]:
        """Return the ``MASK:MASK<x>:SEG<x>COUNT`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``MASK:MASK<x>:SEG<x>COUNT?`` query.
            - Using the ``.verify(value)`` method will send the ``MASK:MASK<x>:SEG<x>COUNT?`` query
              and raise an AssertionError if the returned value does not match ``value``.

        **Info:**
            - ``MASK<x>`` specifies the mask test.
            - ``SEG<x>`` specifies the mask segment.

        Sub-properties:
            - ``.hits``: The ``MASK:MASK<x>:SEG<x>COUNT:HITS`` command.
        """
        return self._segcount

    @property
    def source(self) -> MaskMaskItemSource:
        """Return the ``MASK:MASK<x>:SOUrce`` command.

        **Description:**
            - This command sets or queries analog source for the specified mask test.

        **Usage:**
            - Using the ``.query()`` method will send the ``MASK:MASK<x>:SOUrce?`` query.
            - Using the ``.verify(value)`` method will send the ``MASK:MASK<x>:SOUrce?`` query and
              raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``MASK:MASK<x>:SOUrce value``
              command.

        **SCPI Syntax:**

        ::

            - MASK:MASK<x>:SOUrce {CH<x>|REF<x>|MATH<x>|RFvsTime}
            - MASK:MASK<x>:SOUrce?

        **Info:**
            - ``MASK<x>`` specifies the mask test.
            - ``CH<x>`` specifies an analog channel as source.
            - ``MATH<x>`` specifies a math channel as source.
            - ``REF<x>`` specifies a reference waveform as the source.
            - ``RFvsTime`` specifies a RF vs Time as the source.
        """
        return self._source

    @property
    def test(self) -> MaskMaskItemTest:
        """Return the ``MASK:MASK<x>:TESt`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``MASK:MASK<x>:TESt?`` query.
            - Using the ``.verify(value)`` method will send the ``MASK:MASK<x>:TESt?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        **Info:**
            - ``MASK<x>`` specifies the mask test.

        Sub-properties:
            - ``.state``: The ``MASK:MASK<x>:TESt:STATE`` command.
            - ``.status``: The ``MASK:MASK<x>:TESt:STATUS`` command.
            - ``.threshold``: The ``MASK:MASK<x>:TESt:THReshold`` command.
        """
        return self._test

    @property
    def tolerance(self) -> MaskMaskItemTolerance:
        """Return the ``MASK:MASK<x>:TOLerance`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``MASK:MASK<x>:TOLerance?`` query.
            - Using the ``.verify(value)`` method will send the ``MASK:MASK<x>:TOLerance?`` query
              and raise an AssertionError if the returned value does not match ``value``.

        **Info:**
            - ``MASK<x>`` specifies the mask number.

        Sub-properties:
            - ``.horizontal``: The ``MASK:MASK<x>:TOLerance:HORizontal`` command.
            - ``.updatenow``: The ``MASK:MASK<x>:TOLerance:UPDatenow`` command.
            - ``.vertical``: The ``MASK:MASK<x>:TOLerance:VERTical`` command.
        """
        return self._tolerance


class MaskDelete(SCPICmdWrite):
    """The ``MASK:DELete`` command.

    **Description:**
        - This command deletes all mask segments of the specified mask test.

    **Usage:**
        - Using the ``.write(value)`` method will send the ``MASK:DELete value`` command.

    **SCPI Syntax:**

    ::

        - MASK:DELete 'MASK<x>'

    **Info:**
        - ``MASK<x>`` specifies the mask test. This argument is enclosed in quotes.
    """


class Mask(SCPICmdRead):
    """The ``MASK`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``MASK?`` query.
        - Using the ``.verify(value)`` method will send the ``MASK?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.delete``: The ``MASK:DELete`` command.
        - ``.mask``: The ``MASK:MASK<x>`` command tree.
        - ``.test``: The ``MASK:TESt`` command tree.
    """

    def __init__(self, device: Optional["PIDevice"] = None, cmd_syntax: str = "MASK") -> None:
        super().__init__(device, cmd_syntax)
        self._delete = MaskDelete(device, f"{self._cmd_syntax}:DELete")
        self._mask: Dict[int, MaskMaskItem] = DefaultDictPassKeyToFactory(
            lambda x: MaskMaskItem(device, f"{self._cmd_syntax}:MASK{x}")
        )
        self._test = MaskTest(device, f"{self._cmd_syntax}:TESt")

    @property
    def delete(self) -> MaskDelete:
        """Return the ``MASK:DELete`` command.

        **Description:**
            - This command deletes all mask segments of the specified mask test.

        **Usage:**
            - Using the ``.write(value)`` method will send the ``MASK:DELete value`` command.

        **SCPI Syntax:**

        ::

            - MASK:DELete 'MASK<x>'

        **Info:**
            - ``MASK<x>`` specifies the mask test. This argument is enclosed in quotes.
        """
        return self._delete

    @property
    def mask(self) -> Dict[int, MaskMaskItem]:
        """Return the ``MASK:MASK<x>`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``MASK:MASK<x>?`` query.
            - Using the ``.verify(value)`` method will send the ``MASK:MASK<x>?`` query and raise an
              AssertionError if the returned value does not match ``value``.

        **Info:**
            - ``MASK<x>`` specifies the mask test.

        Sub-properties:
            - ``.count``: The ``MASK:MASK<x>:COUNT`` command.
            - ``.definedby``: The ``MASK:MASK<x>:DEFinedby`` command.
            - ``.display``: The ``MASK:MASK<x>:DISplay`` command.
            - ``.list``: The ``MASK:MASK<x>:LIST`` command.
            - ``.seg``: The ``MASK:MASK<x>:SEG<x>`` command tree.
            - ``.segcount``: The ``MASK:MASK<x>:SEG<x>COUNT`` command tree.
            - ``.source``: The ``MASK:MASK<x>:SOUrce`` command.
            - ``.test``: The ``MASK:MASK<x>:TESt`` command tree.
            - ``.tolerance``: The ``MASK:MASK<x>:TOLerance`` command tree.
        """
        return self._mask

    @property
    def test(self) -> MaskTest:
        """Return the ``MASK:TESt`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``MASK:TESt?`` query.
            - Using the ``.verify(value)`` method will send the ``MASK:TESt?`` query and raise an
              AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.waveforms``: The ``MASK:TESt:WAVEforms`` command.
        """
        return self._test



"""The curvestream commands module.

These commands are used in the following models:
LPD6, MSO2, MSO4, MSO5, MSO5B, MSO5LP, MSO6, MSO6B

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Commands and Queries:

::

    - CURVEStream?
"""
from typing import Optional, TYPE_CHECKING

from .._helpers import SCPICmdRead

if TYPE_CHECKING:
    from tm_devices.drivers.pi.pi_device import PIDevice


class Curvestream(SCPICmdRead):
    """The ``CURVEStream`` command.

    **Description:**
        - This query-only command continuously transfers waveform data from the instrument as it is
          acquired. This command puts the instrument into a streaming data mode, allowing the
          controller to receive waveform records as fast as they are acquired. Use the
          ``DATA:SOURCE`` command to specify the waveform sources. The command supports all the same
          data formatting options as the CURVE command. Control of the instrument through the user
          interface or other external clients is not allowed while in streaming data mode. The GPIB
          controller must take the instrument out of this streaming data mode to terminate the query
          and allow other input sources to resume communication with the instrument. The following
          options are available to transition out of streaming data mode: Send a device clear over
          the bus Send another command or query to the instrument Turning the waveform screen
          display mode off ( ``:DISplay:WAVEform OFF`` ) may increase waveform throughput during
          streaming mode. Using a data encoding of SRIbinary ( ``DATa:ENCdg SRIbinary`` ) may also
          increase the waveform throughput since that is the raw native data format of the
          oscilloscope. While in streaming data mode, two extreme conditions can occur. If the
          waveform records are being acquired slowly (high resolution), configure the controller for
          a long time-out threshold, as the data is not sent out until each complete record is
          acquired. If the waveform records are being acquired rapidly (low resolution), and the
          controller is not reading the data off the bus fast enough, the trigger rate is slowed to
          allow each waveform to be sent sequentially.

    **Usage:**
        - Using the ``.query()`` method will send the ``CURVEStream?`` query.
        - Using the ``.verify(value)`` method will send the ``CURVEStream?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CURVEStream?
    """

    def __init__(
        self, device: Optional["PIDevice"] = None, cmd_syntax: str = "CURVEStream"
    ) -> None:
        super().__init__(device, cmd_syntax)



# ruff: noqa: D402,PLR0913
# pyright: reportConstantRedefinition=none
"""The dataqueue commands module.

These commands are used in the following models: SMU2601B_Pulse

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.
"""
from typing import Optional, TYPE_CHECKING

from .._helpers import BaseTSPCmd

if TYPE_CHECKING:
    from tm_devices.drivers.pi.tsp_device import TSPDevice


# pylint: disable=too-few-public-methods
class Dataqueue(BaseTSPCmd):
    """The ``dataqueue`` command tree.

    Constants:
        - ``.CAPACITY``: The maximum number of entries that you can store in the data queue.
    """

    CAPACITY = "dataqueue.CAPACITY"
    """str: The maximum number of entries that you can store in the data queue."""

    def __init__(self, device: Optional["TSPDevice"] = None, cmd_syntax: str = "dataqueue") -> None:
        super().__init__(device, cmd_syntax)



"""The calibrate commands module.

These commands are used in the following models:
LPD6, MSO2, MSO4, MSO5, MSO5B, MSO5LP, MSO6, MSO6B

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Commands and Queries:

::

    - CALibrate:INTERNal
    - CALibrate:INTERNal:STARt
    - CALibrate:INTERNal:STATus?
    - CALibrate:PWRUpstatus?
    - CALibrate?
"""
from typing import Optional, TYPE_CHECKING

from .._helpers import SCPICmdRead, SCPICmdWriteNoArguments

if TYPE_CHECKING:
    from tm_devices.drivers.pi.pi_device import PIDevice


class CalibratePwrupstatus(SCPICmdRead):
    """The ``CALibrate:PWRUpstatus`` command.

    **Description:**
        - This query-only command returns the current status of the power-up calibration.

    **Usage:**
        - Using the ``.query()`` method will send the ``CALibrate:PWRUpstatus?`` query.
        - Using the ``.verify(value)`` method will send the ``CALibrate:PWRUpstatus?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CALibrate:PWRUpstatus?
    """


class CalibrateInternalStatus(SCPICmdRead):
    """The ``CALibrate:INTERNal:STATus`` command.

    **Description:**
        - This query-only command returns the current status of the signal path calibration.

    **Usage:**
        - Using the ``.query()`` method will send the ``CALibrate:INTERNal:STATus?`` query.
        - Using the ``.verify(value)`` method will send the ``CALibrate:INTERNal:STATus?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CALibrate:INTERNal:STATus?
    """


class CalibrateInternalStart(SCPICmdWriteNoArguments):
    """The ``CALibrate:INTERNal:STARt`` command.

    **Description:**
        - This command (no query form) starts the signal path calibration (SPC) of the analog
          channels. This command is the same as the ``CALIBRATE:INTERNAL`` command. You can use the
          ``CALIBRATE:INTERNAL:STATUS`` query to return the current status of the signal path
          calibration of the instrument.

    **Usage:**
        - Using the ``.write()`` method will send the ``CALibrate:INTERNal:STARt`` command.

    **SCPI Syntax:**

    ::

        - CALibrate:INTERNal:STARt
    """


class CalibrateInternal(SCPICmdWriteNoArguments, SCPICmdRead):
    """The ``CALibrate:INTERNal`` command.

    **Description:**
        - This command (no query form) starts the signal path calibration (SPC) of the instrument.
          You can use the ``CALIBRATE:INTERNAL:STATUS`` query to return the current status of the
          signal path calibration of the instrument.

    **Usage:**
        - Using the ``.write()`` method will send the ``CALibrate:INTERNal`` command.

    **SCPI Syntax:**

    ::

        - CALibrate:INTERNal

    Properties:
        - ``.start``: The ``CALibrate:INTERNal:STARt`` command.
        - ``.status``: The ``CALibrate:INTERNal:STATus`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._start = CalibrateInternalStart(device, f"{self._cmd_syntax}:STARt")
        self._status = CalibrateInternalStatus(device, f"{self._cmd_syntax}:STATus")

    @property
    def start(self) -> CalibrateInternalStart:
        """Return the ``CALibrate:INTERNal:STARt`` command.

        **Description:**
            - This command (no query form) starts the signal path calibration (SPC) of the analog
              channels. This command is the same as the ``CALIBRATE:INTERNAL`` command. You can use
              the ``CALIBRATE:INTERNAL:STATUS`` query to return the current status of the signal
              path calibration of the instrument.

        **Usage:**
            - Using the ``.write()`` method will send the ``CALibrate:INTERNal:STARt`` command.

        **SCPI Syntax:**

        ::

            - CALibrate:INTERNal:STARt
        """
        return self._start

    @property
    def status(self) -> CalibrateInternalStatus:
        """Return the ``CALibrate:INTERNal:STATus`` command.

        **Description:**
            - This query-only command returns the current status of the signal path calibration.

        **Usage:**
            - Using the ``.query()`` method will send the ``CALibrate:INTERNal:STATus?`` query.
            - Using the ``.verify(value)`` method will send the ``CALibrate:INTERNal:STATus?`` query
              and raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CALibrate:INTERNal:STATus?
        """
        return self._status


class Calibrate(SCPICmdRead):
    """The ``CALibrate`` command.

    **Description:**
        - This query returns the status of signal path calibration.

    **Usage:**
        - Using the ``.query()`` method will send the ``CALibrate?`` query.
        - Using the ``.verify(value)`` method will send the ``CALibrate?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CALibrate?

    Properties:
        - ``.internal``: The ``CALibrate:INTERNal`` command.
        - ``.pwrupstatus``: The ``CALibrate:PWRUpstatus`` command.
    """

    def __init__(self, device: Optional["PIDevice"] = None, cmd_syntax: str = "CALibrate") -> None:
        super().__init__(device, cmd_syntax)
        self._internal = CalibrateInternal(device, f"{self._cmd_syntax}:INTERNal")
        self._pwrupstatus = CalibratePwrupstatus(device, f"{self._cmd_syntax}:PWRUpstatus")

    @property
    def internal(self) -> CalibrateInternal:
        """Return the ``CALibrate:INTERNal`` command.

        **Description:**
            - This command (no query form) starts the signal path calibration (SPC) of the
              instrument. You can use the ``CALIBRATE:INTERNAL:STATUS`` query to return the current
              status of the signal path calibration of the instrument.

        **Usage:**
            - Using the ``.write()`` method will send the ``CALibrate:INTERNal`` command.

        **SCPI Syntax:**

        ::

            - CALibrate:INTERNal

        Sub-properties:
            - ``.start``: The ``CALibrate:INTERNal:STARt`` command.
            - ``.status``: The ``CALibrate:INTERNal:STATus`` command.
        """
        return self._internal

    @property
    def pwrupstatus(self) -> CalibratePwrupstatus:
        """Return the ``CALibrate:PWRUpstatus`` command.

        **Description:**
            - This query-only command returns the current status of the power-up calibration.

        **Usage:**
            - Using the ``.query()`` method will send the ``CALibrate:PWRUpstatus?`` query.
            - Using the ``.verify(value)`` method will send the ``CALibrate:PWRUpstatus?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CALibrate:PWRUpstatus?
        """
        return self._pwrupstatus



"""MSO5 device driver module."""
from tm_devices.commands import MSO5Mixin
from tm_devices.drivers.pi.scopes.tekscope.tekscope import TekScope


class MSO5(MSO5Mixin, TekScope):
    """MSO5 device driver."""



"""The export commands module.

These commands are used in the following models:
DPO5KB, DPO70KC, DPO70KD, DPO70KDX, DPO70KSX, DPO7KC, DSA70KC, DSA70KD, MSO5KB, MSO70KC, MSO70KDX

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Commands and Queries:

::

    - EXPort STARt
    - EXPort:FILEName <file path>
    - EXPort:FILEName?
    - EXPort:FORMat {BMP|JPEG|PCX|PNG|TIFF}
    - EXPort:FORMat?
    - EXPort:PALEtte {COLOr|INKSaver|BLACKANDWhite}
    - EXPort:PALEtte?
    - EXPort:READOuts {OFFGRAticule|ONGRAticule}
    - EXPort:READOuts?
    - EXPort:VIEW {FULLSCREEN|GRAticule|FULLNOmenu}
    - EXPort:VIEW?
    - EXPort?
"""
from typing import Optional, TYPE_CHECKING

from .._helpers import SCPICmdRead, SCPICmdWrite

if TYPE_CHECKING:
    from tm_devices.drivers.pi.pi_device import PIDevice


class ExportView(SCPICmdWrite, SCPICmdRead):
    """The ``EXPort:VIEW`` command.

    **Description:**
        - This command sets or queries the area of the screen to be exported.

    **Usage:**
        - Using the ``.query()`` method will send the ``EXPort:VIEW?`` query.
        - Using the ``.verify(value)`` method will send the ``EXPort:VIEW?`` query and raise an
          AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``EXPort:VIEW value`` command.

    **SCPI Syntax:**

    ::

        - EXPort:VIEW {FULLSCREEN|GRAticule|FULLNOmenu}
        - EXPort:VIEW?

    **Info:**
        - ``FULLSCREEN`` displays both the graticule and menu areas of the screen.
        - ``GRAticule`` displays only the graticule area of the screen.
        - ``FULLNOmenu`` displays the full screen but hides any menus or toolbars.
    """


class ExportReadouts(SCPICmdWrite, SCPICmdRead):
    """The ``EXPort:READOuts`` command.

    **Description:**
        - This command sets or queries the area on the screen where the readout appear for export.

    **Usage:**
        - Using the ``.query()`` method will send the ``EXPort:READOuts?`` query.
        - Using the ``.verify(value)`` method will send the ``EXPort:READOuts?`` query and raise an
          AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``EXPort:READOuts value`` command.

    **SCPI Syntax:**

    ::

        - EXPort:READOuts {OFFGRAticule|ONGRAticule}
        - EXPort:READOuts?

    **Info:**
        - ``OFFGRATICULE`` places the readouts off the graticule area.
        - ``ONGRATICULE`` places the readouts on the graticule area for export.
    """


class ExportPalette(SCPICmdWrite, SCPICmdRead):
    """The ``EXPort:PALEtte`` command.

    **Description:**
        - This command sets or queries the export color palette.

    **Usage:**
        - Using the ``.query()`` method will send the ``EXPort:PALEtte?`` query.
        - Using the ``.verify(value)`` method will send the ``EXPort:PALEtte?`` query and raise an
          AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``EXPort:PALEtte value`` command.

    **SCPI Syntax:**

    ::

        - EXPort:PALEtte {COLOr|INKSaver|BLACKANDWhite}
        - EXPort:PALEtte?

    **Info:**
        - ``COLOr`` Hard copy output is color.
        - ``INKSaver`` Hard copy output saves ink.
        - ``BLACKANDwhite`` Hard copy output is black and white.
    """


class ExportFormat(SCPICmdWrite, SCPICmdRead):
    """The ``EXPort:FORMat`` command.

    **Description:**
        - This command sets or queries the image format for exporting waveforms to a file.

    **Usage:**
        - Using the ``.query()`` method will send the ``EXPort:FORMat?`` query.
        - Using the ``.verify(value)`` method will send the ``EXPort:FORMat?`` query and raise an
          AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``EXPort:FORMat value`` command.

    **SCPI Syntax:**

    ::

        - EXPort:FORMat {BMP|JPEG|PCX|PNG|TIFF}
        - EXPort:FORMat?

    **Info:**
        - ``BMP`` specifies BMP image format.
        - ``JPEG`` specifies JPEG image format.
        - ``PCX`` specifies PCX image format.
        - ``PNG`` specifies PNG image format.
        - ``TIFF`` specifies TIFF image format.
    """


class ExportFilename(SCPICmdWrite, SCPICmdRead):
    """The ``EXPort:FILEName`` command.

    **Description:**
        - This command sets or queries the file/path that will be sent export data on the next
          EXPORT command.

    **Usage:**
        - Using the ``.query()`` method will send the ``EXPort:FILEName?`` query.
        - Using the ``.verify(value)`` method will send the ``EXPort:FILEName?`` query and raise an
          AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``EXPort:FILEName value`` command.

    **SCPI Syntax:**

    ::

        - EXPort:FILEName <file path>
        - EXPort:FILEName?

    **Info:**
        - ``<file path>`` specifies that the hard copy is sent to the named file. <file path> is a
          quoted string that defines the file name and path. Input the file path using the form
          ``<drive>:<dir>``/<filename>.<drive> and one or more <dir>s are optional. The file path
          cannot exceed 128 characters. If you do not specify the path with <drive>: and one or more
          <dir>s, the default location is 'C:UsersPublicTektronixTekScopeScreen Captures'. While
          filename extensions are not required, they are highly recommended.
    """


class Export(SCPICmdWrite, SCPICmdRead):
    """The ``EXPort`` command.

    **Description:**
        - This command sends a copy of the waveform to the file path specified by
          ``EXPORT:FILENAME``. The ``EXPort`` query returns image format and file information.

    **Usage:**
        - Using the ``.query()`` method will send the ``EXPort?`` query.
        - Using the ``.verify(value)`` method will send the ``EXPort?`` query and raise an
          AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``EXPort value`` command.

    **SCPI Syntax:**

    ::

        - EXPort STARt
        - EXPort?

    **Info:**
        - ``STARt`` initiates the export.

    Properties:
        - ``.filename``: The ``EXPort:FILEName`` command.
        - ``.format``: The ``EXPort:FORMat`` command.
        - ``.palette``: The ``EXPort:PALEtte`` command.
        - ``.readouts``: The ``EXPort:READOuts`` command.
        - ``.view``: The ``EXPort:VIEW`` command.
    """

    def __init__(self, device: Optional["PIDevice"] = None, cmd_syntax: str = "EXPort") -> None:
        super().__init__(device, cmd_syntax)
        self._filename = ExportFilename(device, f"{self._cmd_syntax}:FILEName")
        self._format = ExportFormat(device, f"{self._cmd_syntax}:FORMat")
        self._palette = ExportPalette(device, f"{self._cmd_syntax}:PALEtte")
        self._readouts = ExportReadouts(device, f"{self._cmd_syntax}:READOuts")
        self._view = ExportView(device, f"{self._cmd_syntax}:VIEW")

    @property
    def filename(self) -> ExportFilename:
        """Return the ``EXPort:FILEName`` command.

        **Description:**
            - This command sets or queries the file/path that will be sent export data on the next
              EXPORT command.

        **Usage:**
            - Using the ``.query()`` method will send the ``EXPort:FILEName?`` query.
            - Using the ``.verify(value)`` method will send the ``EXPort:FILEName?`` query and raise
              an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``EXPort:FILEName value`` command.

        **SCPI Syntax:**

        ::

            - EXPort:FILEName <file path>
            - EXPort:FILEName?

        **Info:**
            - ``<file path>`` specifies that the hard copy is sent to the named file. <file path> is
              a quoted string that defines the file name and path. Input the file path using the
              form ``<drive>:<dir>``/<filename>.<drive> and one or more <dir>s are optional. The
              file path cannot exceed 128 characters. If you do not specify the path with <drive>:
              and one or more <dir>s, the default location is 'C:UsersPublicTektronixTekScopeScreen
              Captures'. While filename extensions are not required, they are highly recommended.
        """
        return self._filename

    @property
    def format(self) -> ExportFormat:
        """Return the ``EXPort:FORMat`` command.

        **Description:**
            - This command sets or queries the image format for exporting waveforms to a file.

        **Usage:**
            - Using the ``.query()`` method will send the ``EXPort:FORMat?`` query.
            - Using the ``.verify(value)`` method will send the ``EXPort:FORMat?`` query and raise
              an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``EXPort:FORMat value`` command.

        **SCPI Syntax:**

        ::

            - EXPort:FORMat {BMP|JPEG|PCX|PNG|TIFF}
            - EXPort:FORMat?

        **Info:**
            - ``BMP`` specifies BMP image format.
            - ``JPEG`` specifies JPEG image format.
            - ``PCX`` specifies PCX image format.
            - ``PNG`` specifies PNG image format.
            - ``TIFF`` specifies TIFF image format.
        """
        return self._format

    @property
    def palette(self) -> ExportPalette:
        """Return the ``EXPort:PALEtte`` command.

        **Description:**
            - This command sets or queries the export color palette.

        **Usage:**
            - Using the ``.query()`` method will send the ``EXPort:PALEtte?`` query.
            - Using the ``.verify(value)`` method will send the ``EXPort:PALEtte?`` query and raise
              an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``EXPort:PALEtte value`` command.

        **SCPI Syntax:**

        ::

            - EXPort:PALEtte {COLOr|INKSaver|BLACKANDWhite}
            - EXPort:PALEtte?

        **Info:**
            - ``COLOr`` Hard copy output is color.
            - ``INKSaver`` Hard copy output saves ink.
            - ``BLACKANDwhite`` Hard copy output is black and white.
        """
        return self._palette

    @property
    def readouts(self) -> ExportReadouts:
        """Return the ``EXPort:READOuts`` command.

        **Description:**
            - This command sets or queries the area on the screen where the readout appear for
              export.

        **Usage:**
            - Using the ``.query()`` method will send the ``EXPort:READOuts?`` query.
            - Using the ``.verify(value)`` method will send the ``EXPort:READOuts?`` query and raise
              an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``EXPort:READOuts value`` command.

        **SCPI Syntax:**

        ::

            - EXPort:READOuts {OFFGRAticule|ONGRAticule}
            - EXPort:READOuts?

        **Info:**
            - ``OFFGRATICULE`` places the readouts off the graticule area.
            - ``ONGRATICULE`` places the readouts on the graticule area for export.
        """
        return self._readouts

    @property
    def view(self) -> ExportView:
        """Return the ``EXPort:VIEW`` command.

        **Description:**
            - This command sets or queries the area of the screen to be exported.

        **Usage:**
            - Using the ``.query()`` method will send the ``EXPort:VIEW?`` query.
            - Using the ``.verify(value)`` method will send the ``EXPort:VIEW?`` query and raise an
              AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``EXPort:VIEW value`` command.

        **SCPI Syntax:**

        ::

            - EXPort:VIEW {FULLSCREEN|GRAticule|FULLNOmenu}
            - EXPort:VIEW?

        **Info:**
            - ``FULLSCREEN`` displays both the graticule and menu areas of the screen.
            - ``GRAticule`` displays only the graticule area of the screen.
            - ``FULLNOmenu`` displays the full screen but hides any menus or toolbars.
        """
        return self._view



# ruff: noqa: D402,PLR0913
# pyright: reportConstantRedefinition=none
"""The beeper commands module.

These commands are used in the following models:
DAQ6510, DMM6500, DMM7510, SMU2450, SMU2460, SMU2461, SMU2470

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Attributes and Functions:

::

    - beeper.beep()
"""
from typing import Optional, TYPE_CHECKING

from .._helpers import BaseTSPCmd, NoDeviceProvidedError

if TYPE_CHECKING:
    from tm_devices.drivers.pi.tsp_device import TSPDevice


class Beeper(BaseTSPCmd):
    """The ``beeper`` command tree.

    Properties/methods:
        - ``.beep()``: The ``beeper.beep()`` function.
    """

    def __init__(self, device: Optional["TSPDevice"] = None, cmd_syntax: str = "beeper") -> None:
        super().__init__(device, cmd_syntax)

    def beep(self, duration: float, frequency: float) -> None:
        """Run the ``beeper.beep()`` function.

        **Description:**
            - This function generates an audible tone.

        **TSP Syntax:**

        ::

            - beeper.beep()

        Args:
            duration: The amount of time to play the tone (0.001 s to 100 s).
            frequency: The frequency of the beep (20 Hz to 8000 Hz).

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            self._device.write(  # type: ignore[union-attr]
                f"{self._cmd_syntax}.beep({duration}, {frequency})"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to run the ``{self._cmd_syntax}.beep()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error
